@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 import logging
+import re
 
 from deep_translator import GoogleTranslator
 from langdetect import detect
@@ -34,7 +35,18 @@ def translate(docs: set[Document], target_lang: str) -> set[Document]:
 
 def _translate(doc: Document, target_lang: str) -> None:
     # The limit of Google Translate Web is less than 5000 chars per request
-    chunks = [doc.text[i:i + 4999] for i in range(0, len(doc.text), 4999)]
+    chunks = _split_text_at_punct(doc.text, 5000)
     for i, chunk in enumerate(chunks):
         chunks[i] = GoogleTranslator(target=target_lang).translate(text=chunk)
     doc.text = "".join(chunks)
+
+
+def _split_text_at_punct(text: str, max_len: int, chunks: list[str] = None) -> list[str]:
+    if chunks is None:
+        chunks = []
+    if len(text) < max_len:
+        return [*chunks, text]
+    match = re.search(r'(?s:.*)[\.!\?]\s', text[:max_len])
+    chunk = text[:match.end()] if match else text[:max_len]
+    chunks.append(chunk)
+    return _split_text_at_punct(text[match.end() if match else max_len:], max_len, chunks)
